@@ -1,7 +1,7 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    Copyright (C) 2004-2010 Institut National de Recherche en Informatique     *)
 (*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
@@ -23,7 +23,7 @@
 (*                                                                               *)
 (*********************************************************************************)
 
-(* $Id: cam_doc_gui.ml 717 2009-09-22 05:40:58Z zoggy $ *)
+(* $Id: cam_doc_gui.ml 749 2010-06-17 06:52:00Z zoggy $ *)
 
 (** Gui for doc searching and browsing. *)
 
@@ -627,7 +627,7 @@ class text_doc =
 	  ()
       |	Odoc_info.Link (s, t) ->
 	  self#put_text ~bold ~fixed t
-      |	Odoc_info.Ref (s, kind_opt) ->
+      |	Odoc_info.Ref (s, kind_opt, _) ->
 	  (
 	   match kind_opt with
 	     None ->
