@@ -1,7 +1,7 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    Copyright (C) 2004-2010 Institut National de Recherche en Informatique     *)
 (*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
@@ -206,6 +206,24 @@ let line_of_char file n =
     Sys_error s ->
       prerr_endline s ;
       0
+
+let char_of_line file n =
+  let ic = open_in file in
+  let rec iter acc l =
+    if l >= n then
+      acc
+    else
+      match
+        try Some (String.length (input_line ic))
+        with End_of_file -> None
+      with
+        None -> acc
+      | Some n -> iter (acc+n+1) (l+1) (* acc+n+1 for the newline character *)
+  in
+  let n = iter 0 0 in
+  close_in ic;
+  n
+;;
 (*c==v=[String.replace_in_string]=1.0====*)
 let replace_in_string ~pat ~subs ~s =
   let len_pat = String.length pat in
