@@ -1,7 +1,7 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    Copyright (C) 2004-2010 Institut National de Recherche en Informatique     *)
 (*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
@@ -23,7 +23,7 @@
 (*                                                                               *)
 (*********************************************************************************)
 
-(* $Id: cam_misc.mli 717 2009-09-22 05:40:58Z zoggy $ *)
+(* $Id: cam_misc.mli 749 2010-06-17 06:52:00Z zoggy $ *)
 
 (** Utils *)
 
@@ -88,6 +88,11 @@ val subdirs : string -> string list
    in a file from a character number. *)
 val line_of_char : string -> int -> int
 
+(** [char_of_line file line] returns the offset of the first character
+     of the given [line] of the give [file]. Line number are zero-based,
+     as the returned character number. *)
+val char_of_line : string -> int -> int
+
 (*i==v=[String.replace_in_string]=1.0====*)
 (** [replace_in_string ~pat ~subs ~s] replaces all occurences of
    pattern [pat] by [subs] in string [s].
