@@ -1,7 +1,7 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    Copyright (C) 2004-2010 Institut National de Recherche en Informatique     *)
 (*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
@@ -312,6 +312,7 @@ class type mode =
     method from_display : string -> string
     method set_to_display : (string -> string) -> unit
     method set_from_display : (string -> string) -> unit
+    method word_re : string
   end
 
 class empty_mode : mode =
@@ -325,6 +326,7 @@ class empty_mode : mode =
     method from_display s = from_display s
     method set_to_display f = to_display <- f
     method set_from_display f = from_display <- f
+    method word_re = "[a-zA-Z0-9]+"
   end
 
 let available_modes = Hashtbl.create 37
@@ -421,7 +423,7 @@ class buffered_file ?(attributes=[]) ?loc ~name ~filename buffer =
 
     method update_source_marks =
       let bookmarks = List.filter
-        (fun (bm_name, (f,_,_)) -> Ed_misc.same_files filename f)
+        (fun (bm_name, (f,_,_)) -> Ed_misc.safe_same_files filename f)
         (Ed_bookmarks.list bookmarks)
       in
       buffer#remove_source_marks
@@ -535,20 +537,21 @@ class buffered_file ?(attributes=[]) ?loc ~name ~filename buffer =
       | Some m -> m#to_display s
 
     method load_file filename =
-      if not (Sys.file_exists filename) then
-        Ed_misc.file_of_string ~file: filename "";
-      (* FIXME: handle errors occuring while opening file *)
-      let text =
-        try self#mode_to_display
-          (self#to_utf8 (Ed_misc.string_of_file filename))
-        with _ -> ""
-      in
-      self#buffer#begin_not_undoable_action ();
-      self#buffer#set_text text;
-      self#buffer#end_not_undoable_action ();
-      self#buffer#set_modified false;
+      if Sys.file_exists filename then
+        begin
+          (* FIXME: handle errors occuring while opening file *)
+          let text =
+            try self#mode_to_display
+              (self#to_utf8 (Ed_misc.string_of_file filename))
+            with _ -> ""
+          in
+          self#buffer#begin_not_undoable_action ();
+          self#buffer#set_text text;
+          self#buffer#end_not_undoable_action ();
+          self#buffer#set_modified false;
+        end;
       self#update_date;
-      self#update_source_marks;
+      self#update_source_marks
 
     method newer_file_exists =
       let d = Ed_misc.mod_date_of_file filename in
@@ -590,6 +593,35 @@ class buffered_file ?(attributes=[]) ?loc ~name ~filename buffer =
         (buffer#get_iter (`OFFSET start))
         (buffer#get_iter (`OFFSET stop))
 
+    method range_from_range_in_file ~left ~right =
+      let from_display = self#mode_from_display (buffer#get_text ()) in
+      let (left, right) =
+        let left =
+          Cam_misc.utf8_string_length
+            (self#mode_to_display
+             (String.sub from_display 0 left))
+        in
+        let right =
+          Cam_misc.utf8_string_length
+            (self#mode_to_display
+             (String.sub from_display 0 right))
+        in
+        (left, right)
+      in
+      (left, right)
+
+    method line_offset_from_line_in_file line =
+      let char_offset = Cam_misc.char_of_line filename line in
+      let from_display = self#mode_from_display (buffer#get_text ()) in
+      Cam_misc.utf8_string_length
+        (self#mode_to_display (String.sub from_display 0 char_offset))
+
+    method select_range_in_file ~left ~right =
+      let (left, right) = self#range_from_range_in_file ~left ~right in
+      let start = buffer#get_iter (`OFFSET left) in
+      let stop = buffer#get_iter (`OFFSET right) in
+      buffer#select_range start stop
+
     initializer
       self#set_syntax_mode stxmode;
       self#load_file filename;
@@ -821,6 +853,20 @@ class sourceview ?(attributes=[]) (topwin : Ed_view.topwin)
     method update_my_location =
       self#set_my_location self#location_in_buffer
 
+    method select_range_in_file ?(jump: [`Left|`Right]option) ~left ~right () =
+      begin
+        match jump with
+          None -> ()
+        | Some `Left ->
+            self#set_location
+              (location_of_iter (file#buffer#get_iter (`OFFSET left)))
+        | Some `Right ->
+            self#set_location
+              (location_of_iter (file#buffer#get_iter (`OFFSET right)))
+      end;
+      file#select_range_in_file ~left ~right
+
+
     method on_cursor_moved =
       if self#has_focus then
         self#update_my_location
@@ -1347,7 +1393,7 @@ let create_buffer ?(attributes=[]) filename =
 
 let get_buffer ?(attributes=[]) filename =
   try
-    if not (Sys.file_exists filename) then raise Not_found;
+(*    if not (Sys.file_exists filename) then raise Not_found;*)
     let b = List.find
       (fun f -> Ed_misc.safe_same_files f#filename filename)
         !buffers
