@@ -1,7 +1,7 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    Copyright (C) 2004-2010 Institut National de Recherche en Informatique     *)
 (*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
@@ -139,6 +139,9 @@ class type mode =
     method from_display : string -> string
     method set_to_display : (string -> string) -> unit
     method set_from_display : (string -> string) -> unit
+
+    (** Definition of a regexp describing characters of words. *)
+    method word_re : string
   end
 
 class empty_mode : mode
@@ -185,6 +188,10 @@ class buffered_file :
       method date : float option
       method encoding : string option
       method filename : string
+
+      (** Return the character offset in the buffer corresponding
+           to the first character of the given line in the file. *)
+      method line_offset_from_line_in_file : int -> int
       method location : int * int
       method mode : mode option
       method mode_key_bindings : (Okey.keyhit_state * string) list
@@ -200,6 +207,15 @@ class buffered_file :
       method to_utf8 : string -> string
       method select_location : location -> unit
       method set_location : int * int -> unit
+
+      (** From a range (in character offsets) in the given file,
+           return the corresponding range in the buffer. *)
+      method range_from_range_in_file : left: int -> right: int -> (int * int)
+
+      (** Select the given range in the buffer. The left and right
+           parameters are character offsets in the file.
+           *)
+      method select_range_in_file : left: int -> right: int -> unit
       method set_mode : mode option -> unit
       method set_name : string -> unit
       method set_source_marks : (string * GSourceView2.source_mark) list -> unit
@@ -300,6 +316,14 @@ class sourceview :
       method save_as : (unit -> unit) option
       method select_location : location -> unit
       method select_location_opt : location option -> unit
+
+        (** Select the given range in the buffer. The left and right
+           parameters are character offsets in the file.
+           @parameter jump can be used to indicate that the insert
+           cursor must be positioned to left or right, or not positioned.
+           *)
+      method select_range_in_file :
+        ?jump: [`Left|`Right] -> left: int -> right: int -> unit -> unit
       method set_file : ?focus_in:bool -> buffered_file -> unit
       method set_label : string -> unit
       method set_location : int * int -> unit
